From 52a317092eb7693c83c4917282283ea53fecd220 Mon Sep 17 00:00:00 2001
From: Sze Howe Koh <szehowe.koh@gmail.com>
Date: Wed, 23 Jan 2013 19:39:47 +0800
Subject: [PATCH] Doc: Fix references to Qt Test

QtTestLib and QTestLib don't exist. The proper name is "QtTest" (code)
or "Qt Test" (English)

http://qt-project.org/wiki/Spelling_Module_Names_in_Qt_Documentation
http://lists.qt-project.org/pipermail/interest/2012-December/005221.html

Files paths in qttestlib.qdocconf can't be changed easily however, as it
breaks things. So, they're left as they are.

Change-Id: Ifbc44ea858c453bedad8cd7723f847e67fc7a85a
Reviewed-by: Oswald Buddenhagen <oswald.buddenhagen@digia.com>
Reviewed-by: Thiago Macieira <thiago.macieira@intel.com>
Reviewed-by: Jerome Pasion <jerome.pasion@digia.com>
---
 examples/qtestlib/README                                  | 4 ++--
 src/corelib/kernel/qobject_p.h                            | 2 +-
 src/testlib/doc/qttestlib.qdocconf                        | 4 ++--
 src/testlib/doc/src/qttest-index.qdoc                     | 2 +-
 src/testlib/qbenchmark.cpp                                | 2 +-
 src/testlib/qbenchmark.h                                  | 2 +-
 src/testlib/qtestcase.cpp                                 | 4 ++--
 src/widgets/kernel/qapplication.cpp                       | 2 +-
 src/widgets/widgets/qsplashscreen.cpp                     | 2 +-
 tests/README                                              | 2 +-
 tests/auto/corelib/xml/qxmlstream/tst_qxmlstream.cpp      | 8 ++++----
 .../widgets/widgets/qdatetimeedit/tst_qdatetimeedit.cpp   | 2 +-
 12 files changed, 18 insertions(+), 18 deletions(-)

diff --git a/examples/qtestlib/README b/examples/qtestlib/README
index 7ca55b2eb3d..d75e8218cd2 100644
--- a/examples/qtestlib/README
+++ b/examples/qtestlib/README
@@ -1,5 +1,5 @@
-The QTestLib framework is a tool for unit testing Qt based applications
-and libraries. QTestLib provides all the functionality commonly found
+The Qt Test framework is a tool for unit testing Qt based applications
+and libraries. Qt Test provides all the functionality commonly found
 in unit testing frameworks as well as extensions for testing graphical
 user interfaces.
 
diff --git a/src/corelib/kernel/qobject_p.h b/src/corelib/kernel/qobject_p.h
index d8bc87d13e5..e4b4ce8b42f 100644
--- a/src/corelib/kernel/qobject_p.h
+++ b/src/corelib/kernel/qobject_p.h
@@ -69,7 +69,7 @@ class QThreadData;
 class QObjectConnectionListVector;
 namespace QtSharedPointer { struct ExternalRefCountData; }
 
-/* for QtTestLib */
+/* for Qt Test */
 struct QSignalSpyCallbackSet
 {
     typedef void (*BeginCallback)(QObject *caller, int signal_or_method_index, void **argv);
diff --git a/src/testlib/doc/qttestlib.qdocconf b/src/testlib/doc/qttestlib.qdocconf
index 2a2a1e4ea0f..3785bd6503e 100644
--- a/src/testlib/doc/qttestlib.qdocconf
+++ b/src/testlib/doc/qttestlib.qdocconf
@@ -15,8 +15,8 @@ qhp.QtTestLib.virtualFolder       = qttest
 qhp.QtTestLib.indexTitle          = Qt Test
 qhp.QtTestLib.indexRoot           =
 
-qhp.QtTestLib.filterAttributes    = qttestlib 5.0.1 qtrefdoc
-qhp.QtTestLib.customFilters.Qt.name = QtTestLib 5.0.1
+qhp.QtTestLib.filterAttributes    = qttest 5.0.1 qtrefdoc
+qhp.QtTestLib.customFilters.Qt.name = QtTest 5.0.1
 qhp.QtTestLib.customFilters.Qt.filterAttributes = qttest 5.0.1
 
 qhp.QtTestLib.subprojects         = classes
diff --git a/src/testlib/doc/src/qttest-index.qdoc b/src/testlib/doc/src/qttest-index.qdoc
index fb0b6398475..db42db1687a 100644
--- a/src/testlib/doc/src/qttest-index.qdoc
+++ b/src/testlib/doc/src/qttest-index.qdoc
@@ -25,7 +25,7 @@
 **
 ****************************************************************************/
 /*!
-    \page qttestlib-index.html
+    \page qttest-index.html
     \title Qt Test
     \brief Provides classes for unit testing Qt applications and libraries.
 
diff --git a/src/testlib/qbenchmark.cpp b/src/testlib/qbenchmark.cpp
index 450dce46ab9..796d817ae2e 100644
--- a/src/testlib/qbenchmark.cpp
+++ b/src/testlib/qbenchmark.cpp
@@ -266,7 +266,7 @@ quint64 QTest::endBenchmarkMeasurement()
     Sets the benchmark result for this test function to \a result.
 
     Use this function if you want to report benchmark results without
-    using the QBENCHMARK macro. Use \a metric to specify how QTestLib
+    using the QBENCHMARK macro. Use \a metric to specify how Qt Test
     should interpret the results.
 
     The context for the result will be the test function name and any
diff --git a/src/testlib/qbenchmark.h b/src/testlib/qbenchmark.h
index 942e8f69fd9..f1669552496 100644
--- a/src/testlib/qbenchmark.h
+++ b/src/testlib/qbenchmark.h
@@ -58,7 +58,7 @@ namespace QTest
 //  -------------
 //
 // The QBenchmarkIterationController class is not a part of the
-// QTestlib API. It exists purely as an implementation detail.
+// Qt Test API. It exists purely as an implementation detail.
 //
 //
 class Q_TESTLIB_EXPORT QBenchmarkIterationController
diff --git a/src/widgets/kernel/qapplication.cpp b/src/widgets/kernel/qapplication.cpp
index 95a8840a9d7..4c6d8cfdc72 100644
--- a/src/widgets/kernel/qapplication.cpp
+++ b/src/widgets/kernel/qapplication.cpp
@@ -2720,7 +2720,7 @@ bool QApplication::notify(QObject *receiver, QEvent *e)
 
     if(e->spontaneous()) {
         // Capture the current mouse and keyboard states. Doing so here is
-        // required in order to support QTestLib synthesized events. Real mouse
+        // required in order to support Qt Test synthesized events. Real mouse
         // and keyboard state updates from the platform plugin are managed by
         // QGuiApplicationPrivate::process(Mouse|Wheel|Key|Touch|Tablet)Event();
         switch (e->type()) {
diff --git a/src/widgets/widgets/qsplashscreen.cpp b/src/widgets/widgets/qsplashscreen.cpp
index 1ad8fe07cd3..3711b2f43e3 100644
--- a/src/widgets/widgets/qsplashscreen.cpp
+++ b/src/widgets/widgets/qsplashscreen.cpp
@@ -225,7 +225,7 @@ void QSplashScreen::clearMessage()
     repaint();
 }
 
-// A copy of QTestLib's qWaitForWindowExposed() and qSleep().
+// A copy of Qt Test's qWaitForWindowExposed() and qSleep().
 inline static bool waitForWindowExposed(QWindow *window, int timeout = 1000)
 {
     enum { TimeOutMs = 10 };
diff --git a/tests/README b/tests/README
index f94d5a2f13b..5a8f2a21cd5 100644
--- a/tests/README
+++ b/tests/README
@@ -1,4 +1,4 @@
-This directory contains autotests and benchmarks based on QTestlib. In order
+This directory contains autotests and benchmarks based on Qt Test. In order
 to run the autotests reliably, you need to configure a desktop to match the
 test environment that these tests are written for.
 
diff --git a/tests/auto/widgets/widgets/qdatetimeedit/tst_qdatetimeedit.cpp b/tests/auto/widgets/widgets/qdatetimeedit/tst_qdatetimeedit.cpp
index ca2f8e7afc5..9ecb0650c5d 100644
--- a/tests/auto/widgets/widgets/qdatetimeedit/tst_qdatetimeedit.cpp
+++ b/tests/auto/widgets/widgets/qdatetimeedit/tst_qdatetimeedit.cpp
@@ -3218,7 +3218,7 @@ void tst_QDateTimeEdit::cachedDayTest()
     testWidget->setDate(QDate(2007, 1, 30));
     testWidget->setCurrentSection(QDateTimeEdit::DaySection);
     //QTest::keyClick(testWidget->lineEdit(), Qt::Key_Up); // this doesn't work
-    //on Mac. QTestLib bug? ###
+    //on Mac. Qt Test bug? ###
     QTest::keyClick(testWidget, Qt::Key_Up);
     testWidget->setCurrentSection(QDateTimeEdit::MonthSection);
     QTest::keyClick(testWidget, Qt::Key_Up);
diff --git a/src/testlib/qtestcase.cpp b/src/testlib/qtestcase.cpp
index 951631ba334..987c5d88b26 100644
--- a/src/testlib/qtestcase.cpp
+++ b/src/testlib/qtestcase.cpp
@@ -1837,7 +1837,7 @@ char *toHexRepresentation(const char *ba, int length)
      * running out of memory and flooding things when the byte array
      * is large.
      *
      * maxLen can't be for example 200 because QTestLib is sprinkled with fixed
      * size char arrays.
      * */
     const int maxLen = 50;
@@ -2037,7 +2037,7 @@ FatalSignalHandler::~FatalSignalHandler()
     are executed if they exist. See \l{Creating a Test} for more details.
 
     Optionally, the command line arguments \a argc and \a argv can be provided.
-    For a list of recognized arguments, read \l {QTestLib Command Line Arguments}.
+    For a list of recognized arguments, read \l {Qt Test Command Line Arguments}.
 
     The following example will run all tests in \c MyTestObject:
 
@@ -1837,7 +1837,7 @@ char *toHexRepresentation(const char *ba, int length)
      * is large.
      *
-     * maxLen can't be for example 200 because QTestLib is sprinkled with fixed
+     * maxLen can't be for example 200 because Qt Test is sprinkled with fixed
      * size char arrays.
      * */
diff --git a/tests/auto/corelib/xml/qxmlstream/tst_qxmlstream.cpp b/tests/auto/corelib/xml/qxmlstream/tst_qxmlstream.cpp
index 73f89115af2..d2e090bf53b 100644
--- a/tests/auto/corelib/xml/qxmlstream/tst_qxmlstream.cpp
+++ b/tests/auto/corelib/xml/qxmlstream/tst_qxmlstream.cpp
@@ -224,7 +224,7 @@ static QString documentElement(const QByteArray &document)
  * Since this suite is fairly large, it runs the tests sequentially in order to not
  * have them all loaded into memory at once. In this way, the maximum memory usage stays
  * low, which means one can run valgrind on this test. However, the drawback is that
  * QTestLib's usual error reporting and testing mechanisms are slightly bypassed.
  *
  * Part of this code is a manual, ad-hoc implementation of xml:base.
  *
@@ -611,11 +611,11 @@ void tst_QXmlStream::reportFailures_data()
     QTest::addColumn<QString>("description");
 
     /* We loop over all our failures(if any!), and output them such
      * that they appear in the QTestLib log. */
     for(int i = 0; i < len; ++i)
         QTest::newRow(m_handler.failures.at(i).first.toLatin1().constData()) << true << m_handler.failures.at(i).second;
 
-    /* We need to add at least one column of test data, otherwise QTestLib complains. */
+    /* We need to add at least one column of test data, otherwise Qt Test complains. */
     if(len == 0)
         QTest::newRow("Whole test suite passed") << false << QString();
 
@@ -1140,7 +1140,7 @@ void tst_QXmlStream::crashInUTF16Codec() const
 }
 
 /*
-  In addition to QTestLib's flags, one can specify "-c <filename>" and have that file output in its canonical form.
+  In addition to Qt Test's flags, one can specify "-c <filename>" and have that file output in its canonical form.
 */
 int main(int argc, char *argv[])
 {
@@ -224,7 +224,7 @@ static QString documentElement(const QByteArray &document)
  * have them all loaded into memory at once. In this way, the maximum memory usage stays
  * low, which means one can run valgrind on this test. However, the drawback is that
- * QTestLib's usual error reporting and testing mechanisms are slightly bypassed.
+ * Qt Test's usual error reporting and testing mechanisms are slightly bypassed.
  *
  * Part of this code is a manual, ad-hoc implementation of xml:base.
@@ -611,11 +611,11 @@ void tst_QXmlStream::reportFailures_data()
 
     /* We loop over all our failures(if any!), and output them such
-     * that they appear in the QTestLib log. */
+     * that they appear in the Qt Test log. */
     for(int i = 0; i < len; ++i)
         QTest::newRow(m_handler.failures.at(i).first.toLatin1().constData()) << true << m_handler.failures.at(i).second;
-- 
GitLab